@@ -7,22 +7,32 @@ module RubyDebianDev
   end
 
   # XXX the default Ruby must come first here
-
-  has_support_for 'ruby2.7' do
+  has_support_for 'ruby3.1' do
     {
-      version:             '2.7',
-      binary:              '/usr/bin/ruby2.7',
-      api_version:         '2.7.0',
-      shared_library:      'libruby2.7',
-      min_ruby_version:    '1:2.7~0',
-      ruby_upper_bound:    '1:2.8~',
+      version:             '3.1',
+      binary:              '/usr/bin/ruby3.1',
+      api_version:         '3.1.0',
+      shared_library:      'libruby3.1',
+      min_ruby_version:    '1:3.1~0',
+      ruby_upper_bound:    '1:3.2~',
+    }
+  end
+
+  has_support_for 'ruby3.0' do
+    {
+      version:             '3.0',
+      binary:              '/usr/bin/ruby3.0',
+      api_version:         '3.0.0',
+      shared_library:      'libruby3.0',
+      min_ruby_version:    '1:3.0~0',
+      ruby_upper_bound:    '1:3.1~',
     }
   end
 
   def self.min_ruby_dependency_for(shared_library)
     RUBY_INTERPRETERS.each do |int,data|
       if data[:shared_library] == shared_library
-        return "ruby (>= %s)" % data[:min_ruby_version]
+        return "libruby (>= %s)" % data[:min_ruby_version]
       end
     end
     return nil
@@ -35,7 +45,7 @@ module RubyDebianDev
     end
     sort.close_write()
     version = sort.read.split.last
-    "ruby (<< #{version})"
+    "libruby (<< #{version})"
   end
 
   #################################################################
